import 'package:flutter/material.dart';
import 'package:form_field_validator/form_field_validator.dart';
import 'package:vegigo2_ui_common/theme/colors.dart';
import 'package:vegigo2_ui_common/util/size_config.dart';

class DatePickerField extends StatefulWidget {
  final String initialValue;
  final DateTime firstDate;
  final DateTime lastDate;
  final ValueChanged<String> onChanged;
  final String labelText;
  final TextFieldValidator validator;
  final Color iconColor;

  DatePickerField({
    Key key,
    this.initialValue = '',
    @required this.firstDate,
    @required this.lastDate,
    @required this.onChanged,
    @required this.labelText,
    this.validator,
    @required this.iconColor
  }) : super(key: key);

  @override
  _DatePickerFieldState createState() => _DatePickerFieldState();
}

class _DatePickerFieldState extends State<DatePickerField> {
  final TextEditingController _dateController = TextEditingController();

  @override
  void initState() {
    super.initState();
    _dateController.text = widget.initialValue;
  }

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      readOnly: true,
      textAlign: TextAlign.center,
      keyboardType: TextInputType.datetime,
      decoration: InputDecoration(
        labelText: widget.labelText,
        labelStyle: Theme.of(context).textTheme.subtitle1.copyWith(
          fontSize: 16 * SizeConfig.textMultiplier,
          color: DARK_GREY_3,
        ),
        border: OutlineInputBorder(
          borderRadius: BorderRadius.circular(60 * SizeConfig.widthMultiplier),
          borderSide: BorderSide(color: LIGHT_GREY_4),
        ),
        suffixIcon: IconButton(
          icon: Icon(
            Icons.date_range_rounded,
            color: widget.iconColor,
          ),
          onPressed: () => _selectDate(context),
        ),
      ),
      style: Theme.of(context).textTheme.subtitle1.copyWith(fontSize: 16 * SizeConfig.textMultiplier),
      validator: widget.validator,
      controller: _dateController,
    );
  }

  Future<void> _selectDate(BuildContext context) async {
    final DateTime pickedDate = await showDatePicker(
      context: context,
      initialDate: DateTime.now(),
      firstDate: widget.firstDate,
      lastDate: widget.lastDate,
    );
    if (pickedDate != null){
      final String dateString = pickedDate.toIso8601String().substring(0, 10);
      _dateController.text = dateString;
      widget.onChanged(dateString);
    }
  }
}