import 'package:flutter/material.dart';
import 'package:otp_text_field/otp_text_field.dart';
import 'package:vegigo2_ui_common/util/constants.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';

class EmailOtpVerificationForm extends StatefulWidget {

  final String email;
  final bool isInvalidCode;
  final ValueChanged<String> onSubmitHandler;
  final int otpLength;
  final String invalidCodeMessage;

  EmailOtpVerificationForm({
    @required this.email,
    @required this.isInvalidCode,
    @required this.onSubmitHandler,
    this.otpLength = 6,
    this.invalidCodeMessage = Constants.INVALID_VERIFICATION_CODE,
  });

  @override
  _EmailOtpVerificationFormState createState() => _EmailOtpVerificationFormState();
}

class _EmailOtpVerificationFormState extends State<EmailOtpVerificationForm> {

  String _verificationCode = '';

  @override
  Widget build(BuildContext context) {
    return Form(
      child: Column(
        children: <Widget>[
          OTPTextField(
            length: widget.otpLength,
            width: MediaQuery.of(context).size.width,
            fieldWidth: 20.0,
            style: TextStyle(fontSize: 20.0 * SizeConfig.textMultiplier),
            onCompleted: (String value) {
              setState(() {
                _verificationCode = value;
              });
            },
            onChanged: (String value) {
              setState(() {
                _verificationCode = value;
              });
            },
            textFieldAlignment: MainAxisAlignment.spaceAround,
          ),
          Container(
            padding: const EdgeInsets.only(top: 10.0),
            alignment: Alignment.centerLeft,
            child: Text(
              widget.isInvalidCode ? widget.invalidCodeMessage : '',
              style: Theme.of(context).textTheme.bodyText1.copyWith(color: Colors.red)
            ),
          ),
          SizedBox(height: 40.0 * SizeConfig.heightMultiplier),
          PrimaryButton(
            title: Constants.SUBMIT_LABEL,
            textColor: Colors.white,
            onButtonPressed: _verificationCode.length == widget.otpLength
              ? () => widget.onSubmitHandler(_verificationCode)
              : null
          ),
        ],
      ),
    );
  }
}
