import 'package:flutter/material.dart';

class SliderRoute extends PageRouteBuilder {
  final Widget page;
  final RouteTransitionDirection transitionDirection;

  SliderRoute({
    @required this.page,
    this.transitionDirection = RouteTransitionDirection.left // Default Route transition will be from Right -> Left
  }) : super(
    pageBuilder: (
      BuildContext context,
      Animation<double> animation,
      Animation<double> secondaryAnimation,
    ) => page,
    transitionDuration: const Duration(milliseconds: 500),
    reverseTransitionDuration: const Duration(milliseconds: 500),
    transitionsBuilder: (
      BuildContext context,
      Animation<double> animation,
      Animation<double> secondaryAnimation,
      Widget child,
    ) => SlideTransition(
      position: Tween<Offset>(
        begin: transitionDirection.transitionOffset,
        end: Offset.zero
      ).animate(animation),
      child: child,
    ),
  );
}

enum RouteTransitionDirection {
  left,
  right,
  top,
  bottom
}

extension RouteTransitionDirectionExtension on RouteTransitionDirection {

  static const transitionOffsets = {
    RouteTransitionDirection.left: const Offset(1, 0),
    RouteTransitionDirection.top: const Offset(0, 1),
    RouteTransitionDirection.right: const Offset(-1, 0),
    RouteTransitionDirection.bottom: const Offset(0, -1)
  };

  Offset get transitionOffset => transitionOffsets[this];
}
