import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;
import 'package:vegigo2_ui_common/util/constants.dart';

class SplashScreenLayout extends StatelessWidget {
  final String splashBackground;
  final String vegigoLogo;
  final String hexanovateLogo;
  final bool vegigoLogoVisibility;
  final bool hexanovateLogoVisibility;

  SplashScreenLayout({
    @required this.splashBackground,
    @required this.vegigoLogo,
    @required this.hexanovateLogo,
    this.vegigoLogoVisibility = false,
    this.hexanovateLogoVisibility = false
  });

  @override
  Widget build(BuildContext context) {
    return Stack(
      fit: StackFit.expand,
      children: <Widget>[
        Container(
          height: MediaQuery.of(context).size.height,
          width: double.infinity,
          decoration: BoxDecoration(
            color: Colors.black,
            image: DecorationImage(
              image: AssetImage(splashBackground),
              fit: BoxFit.cover
            )
          ),
        ),
        Column(
          children: <Widget>[
            Expanded(
              flex: 5,
              child: AnimatedOpacity(
                opacity: vegigoLogoVisibility ? 1.0 : 0.0,
                duration: Duration(milliseconds: 500),
                child: Container(
                  child: Image.asset(vegigoLogo),
                ),
              ),
            ),
            Expanded(
              child: AnimatedOpacity(
                opacity: hexanovateLogoVisibility ? 1.0 : 0.0,
                duration: Duration(milliseconds: 500),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.end,
                  children: <Widget>[
                    Padding(
                      padding: const EdgeInsets.only(left: 100.0, bottom: 10.0),
                      child: Text(
                        Constants.splashScreenPoweredBy,
                        softWrap: true,
                        textAlign: TextAlign.right,
                        style: Theme.of(context).textTheme.headline4.merge(
                          TextStyle(color: colors.SPLASH_PAGE_TEXT)
                        )
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.only(left: 170.0, bottom: 20.0),
                      child: Image.asset(hexanovateLogo),
                    )
                  ],
                ),
              ),
            )
          ],
        )
      ],
    );
  }
}
