import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';

class Product extends Equatable {
  final String id;
  final String title;
  final String regionalName;
  final String brand;
  final String thumbnail;
  final String categoryId;
  final String description;
  final List<UnitPriceMapping> unitPriceMappings;
  final double discountRatio;
  final bool featured;
  final bool active;
  final bool availability;
  final bool special;

  Product({
    @required this.id,
    @required this.title,
    this.regionalName,
    this.brand,
    @required this.thumbnail,
    @required this.categoryId,
    @required this.description,
    @required this.unitPriceMappings,
    this.discountRatio,
    @required this.featured,
    @required this.active,
    @required this.availability,
    @required this.special,
  });

  bool isSearchable(String keyword) {
    return title.toLowerCase().contains(keyword.toLowerCase());
  }

  bool get hasDiscount => discountRatio > 0;

  UnitPriceMapping get defaultUnitPriceMapping {
    return unitPriceMappings.firstWhere(
            (UnitPriceMapping unitPriceMapping) => unitPriceMapping.isDefault == true,
        orElse: () => unitPriceMappings[0] as UnitPriceMappingModel // Not sure why this typecast is required, but when removed, it was throwing typecast exception
    );
  }

  UnitPriceMapping getUnitPriceMappingById(String id) {
    return unitPriceMappings.firstWhere((UnitPriceMapping unitPriceMapping) => unitPriceMapping.id == id);
  }

  @override
  List<Object> get props => [
    id,
    title,
    regionalName,
    brand,
    thumbnail,
    categoryId,
    discountRatio,
    unitPriceMappings,
    featured,
    active,
    availability,
    description,
    special
  ];
}
