import 'package:meta/meta.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';

class OrderProductModel extends OrderProduct {
  OrderProductModel({
    @required String id,
    @required String productId,
    @required String title,
    @required String thumbnail,
    @required double discountRatio,
    @required int quantity,
    @required UnitPriceMappingModel unitPriceMapping,
    @required OrderProductCategoryModel productCategory,
  }): super(
      id: id,
      productId: productId,
      title: title,
      thumbnail: thumbnail,
      discountRatio: discountRatio,
      quantity: quantity,
      unitPriceMapping: unitPriceMapping,
      productCategory: productCategory
  );

  OrderProductModel.fromParent(OrderProduct orderProduct)
    : super(
      id: orderProduct.id,
      productId: orderProduct.productId,
      title: orderProduct.title,
      thumbnail: orderProduct.thumbnail,
      discountRatio: orderProduct.discountRatio,
      quantity: orderProduct.quantity,
      unitPriceMapping: UnitPriceMappingModel.fromParent(orderProduct.unitPriceMapping),
      productCategory: OrderProductCategoryModel.fromParent(orderProduct.productCategory),
    );

  factory OrderProductModel.fromJson(Map<String, dynamic> json) {
    return OrderProductModel(
        id: json['id'].toString(),
        productId: json['productId'] as String,
        title: json['title'] as String,
        thumbnail: json['thumbnail'] as String,
        discountRatio: double.parse(json['discountRatio'].toString()),
        quantity: json['quantity'] as int,
        unitPriceMapping: UnitPriceMappingModel.fromJson(json['unitPriceMapping'] as Map<String, dynamic>),
        productCategory: OrderProductCategoryModel.fromJson(json['category'] as Map<String, dynamic>)
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id,
      'productId': productId,
      'title': title,
      'thumbnail': thumbnail,
      'discountRatio': discountRatio,
      'quantity': quantity,
      'unitPriceMapping': unitPriceMapping,
      'category': (productCategory as OrderProductCategoryModel).toJson()
    };
  }

  static List<OrderProductModel> fromJsonArray(List<dynamic> jsonArray) {
    return jsonArray.map((jsonProduct) => OrderProductModel.fromJson(jsonProduct as Map<String, dynamic>)).toList();
  }

  static List<Map<String, dynamic>> toJsonArray(List<OrderProductModel> orderProducts) {
    return orderProducts.map((OrderProductModel orderProduct) => orderProduct.toJson()).toList();
  }

  static List<OrderProductModel> fromParentList(List<OrderProduct> orderProducts) {
    return orderProducts.map((OrderProduct orderProduct) => OrderProductModel.fromParent(orderProduct)).toList();
  }
}

class OrderProductCategoryModel extends OrderProductCategory {
  OrderProductCategoryModel({
    @required String id,
    @required String title,
  }): super(
    id: id,
    title: title,
  );

  OrderProductCategoryModel.fromParent(OrderProductCategory orderProductCategory)
    : super(
      id: orderProductCategory.id,
      title: orderProductCategory.title,
    );

  factory OrderProductCategoryModel.fromJson(Map<String, dynamic> json) {
    return OrderProductCategoryModel(
      id: json['id'].toString(),
      title: json['title'] as String,
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'id': id,
      'title': title,
    };
  }
}