import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:meta/meta.dart';
import 'package:vegigo2_ui_common/entities/store/time_interval.dart';

class TimeIntervalModel extends TimeInterval {
  final TimeOfDay startTime;
  final TimeOfDay endTime;

  TimeIntervalModel({
    @required this.startTime,
    @required this.endTime,
  }) : super(startTime: startTime, endTime: endTime);

  factory TimeIntervalModel.fromParent(TimeInterval timeInterval) {
    return TimeIntervalModel(
      startTime: timeInterval != null ? timeInterval.startTime : null, 
      endTime: timeInterval != null ? timeInterval.endTime : null,
    );
  }

  factory TimeIntervalModel.fromJson(Map<String, dynamic> json) {
    return TimeIntervalModel(
      startTime: _getTimeOfDayFromString(json['startTime'] as String),
      endTime: _getTimeOfDayFromString(json['endTime'] as String),
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'startTime': _formatTimeOfDay(startTime),
      'endTime': _formatTimeOfDay(endTime),
    };
  }

  // @Param timeString: "09:30 PM"
  static TimeOfDay _getTimeOfDayFromString(String timeString) {
    final List<String> splitTimeString = timeString.split(' '); // ["09:30", "PM"]

    final String postMeridiem = 'PM';
    final String meridiem = splitTimeString[1]; // "PM"
    final List<String> hrsAndMinutes = splitTimeString[0].split(':'); // ["09", "30"]

    int hrs = int.parse(hrsAndMinutes[0]); // 9
    final int minutes = int.parse(hrsAndMinutes[1]); // 30

    if (meridiem == postMeridiem) {
      if (hrs < 12) {
        hrs += 12; // 21
      }
    } else {
      if (hrs == 12) {
        hrs = 0;
      }
    }

    return TimeOfDay(hour: hrs, minute: minutes); // 21:30
  }

  String _formatTimeOfDay(TimeOfDay tod) {
    final now = new DateTime.now();
    final dt = DateTime(now.year, now.month, now.day, tod.hour, tod.minute);
    final format = DateFormat.jm();
    return format.format(dt);
  }
}
