import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';

class SizeConfig {
  final double screenWidthDivider;
  final double screenHeightDivider;

  SizeConfig({
    this.screenWidthDivider = 375.0,
    this.screenHeightDivider = 812.0
  });

  static double _screenWidth;
  static double _screenHeight;
  static double _blockWidth = 0;
  static double _blockHeight = 0;

  static double textMultiplier;
  static double imageSizeMultiplier;
  static double heightMultiplier;
  static double widthMultiplier;
  static bool isPortrait = true;
  static bool isMobilePortrait = false;

  void init(BoxConstraints constraints) {
    _screenWidth = constraints.maxWidth;
    _screenHeight = constraints.maxHeight;
    
    // Our Figma mockups are made on a 385x812 device.
    // Dividing our screen size by these dimension converts 
    // every screen into 375 logical pixels wide. (and 812 height)

    _blockWidth = _screenWidth / screenWidthDivider;
    _blockHeight = _screenHeight / screenHeightDivider;

    // Now we can use the exact values used in figma.
    // Just use the respective multiplier to convert it
    // to the absolute value that flutter uses.
    
    textMultiplier = _blockHeight;
    imageSizeMultiplier = _blockWidth;
    heightMultiplier = _blockHeight;
    widthMultiplier = _blockWidth;

    logger.i('ScreenHeight: $_screenHeight\nScreenWidth: $_screenWidth');
  }
}