import 'package:flutter/material.dart';
import 'package:vegigo2_ui_common/vegigo2_ui_common.dart';
import 'package:vegigo2_ui_common/util/constants.dart';
import 'package:vegigo2_ui_common/theme/colors.dart' as colors;


class UnitPriceDropdown extends StatelessWidget {
  final Product product;
  final UnitPriceMapping selectedUnitPriceMapping;
  final ValueChanged<String> onChangeHandler;

  UnitPriceDropdown({
    @required this.product,
    @required this.selectedUnitPriceMapping,
    @required this.onChangeHandler,
  });

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(top: 5.0),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        children: [
          Padding(
            padding: const EdgeInsets.only(right: 8.0),
            child: Text(
              Constants.QUANTITY_PER_TEXT,
              style: Theme.of(context).textTheme.bodyText2.merge(TextStyle(fontSize: 13.0)),
            ),
          ),
          _unitPriceDropdown(context),
        ],
      ),
    );
  }

  Widget _unitPriceDropdown(BuildContext context) {
    return Container(
      padding: const EdgeInsets.only(left: 8.0),
      decoration: ShapeDecoration(
        shape: RoundedRectangleBorder(
          side: BorderSide(color: colors.GREY),
          borderRadius: BorderRadius.all(Radius.circular(40.0)),
        ),
      ),
      child: DropdownButton<String>(
          isDense: true,
          underline: Container(), // To remove underline
          value: selectedUnitPriceMapping.id,
          items: product.unitPriceMappings.map((UnitPriceMapping unitPriceMapping) {
            return _uniPriceDropdownMenuItem(context, unitPriceMapping);
          }).toList(),
          icon: Icon(Icons.arrow_drop_down, color: colors.DARK_GREEN),
          style: Theme.of(context).textTheme.subtitle1,
          onChanged: (String value) {
            onChangeHandler(value);
          }
      ),
    );
  }

  DropdownMenuItem<String> _uniPriceDropdownMenuItem(BuildContext context, UnitPriceMapping unitPriceMapping) {
    return DropdownMenuItem<String>(
      value: unitPriceMapping.id,
      child: Text(
        '${unitPriceMapping.magnitude} ${unitPriceMapping.unit.abbr}',
        style: Theme.of(context).textTheme.bodyText2.copyWith(
            color: colors.DARK_GREEN,
            fontSize: 11.0
        ),
      )
    );
  }
}
